/*
 *  eb60_board.h
 *  Board support for the GB60 board.
 *
 *  Created by Stefan Robl on 21.01.06.
 *  Copyright 2006 Stefan Robl <stefan@qdev.de>. All rights reserved.
 *
 */

#ifndef __GB60_BOARD_H
#define __GB60_BOARD_H

#include "emTypes.h"


#define GB60_LED_RED    0x01
#define GB60_LED_GREEN  0x02
#define GB60_LEDS_MASK  (GB60_LED_RED | GB60_LED_GREEN)

#define GB60_NUMBER_OF_TIMERS   6
#define GB60_NUMBER_OF_PWMS     5

void gb60_serialInit(void);
void gb60_serialPutC(char c);
char gb60_serialGetC(void);
void gb60_serialPutStr(const char *str);

void gb60_initLEDs(void);
void gb60_setLEDs(uint8 state, uint8 mask);
void gb60_toggleLEDs(uint8 leds);

void gb60_initADC(uint8 mask);
uint16 gb60_readADC(uint8 adcNr);
uint16 gb60_readADCSampled(uint8 adcNr, uint8 samples);

void gb60_initFrequency(void);
void gb60_setFrequency(uint16 frequency);


void gb60_init_PWM_Timer(void);

void gb60_startTimer(uint8 timerNr, uint16 msDelay);
void gb60_stopTimer(uint8 timerNr);
uint16 gb60_getTimer_ms(uint8 timerNr);
boolean gb60_checkTimerFinished(uint8 timerNr);
void gb60_delayUsingTimer(uint8 timerNr, uint16 ms);

void gb60_setPWMEnabled(uint8 pwmNr, boolean enable);
void gb60_setPWMValue(uint8 pwmNr, uint8 value);

#endif